package TestApp::CustomWorkflow;

use warnings;
use strict;
use v5.14.0;
use base qw( Workflow );

$TestApp::CustomWorkflow::VERSION = '0.01';

1;
